@@ -85,7 +85,7 @@ bool KonsoleKalendar::printCalendarList()
 {
     Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(),
                                                                        Akonadi::CollectionFetchJob::Recursive);
-    QStringList mimeTypes = QStringList() << QStringLiteral("text/calendar")
+    const QStringList mimeTypes = QStringList() << QStringLiteral("text/calendar")
                                           << KCalendarCore::Event::eventMimeType()
                                           << KCalendarCore::Todo::todoMimeType()
                                           << KCalendarCore::Journal::journalMimeType();
@@ -105,9 +105,20 @@ bool KonsoleKalendar::printCalendarList()
         cout << i18n("There are no calendars available.").toLocal8Bit().data() << endl;
     } else {
         cout << "--------------------------" << endl;
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
         auto mimeTypeSet = mimeTypes.toSet();           // set changes by run method intersect
+#else
+        auto mimeTypeSet = QSet<QString>(mimeTypes.begin(), mimeTypes.end());           // set changes by run method intersect
+#endif
         foreach (const Akonadi::Collection &collection, collections) {
-            if (!mimeTypeSet.intersect(collection.contentMimeTypes().toSet()).isEmpty()) {
+            const QStringList contentMimeTypes = collection.contentMimeTypes();
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
+            auto collectionMimeTypeSet = contentMimeTypes.toSet();
+#else
+            auto collectionMimeTypeSet = QSet<QString>(contentMimeTypes.begin(), contentMimeTypes.end());
+#endif
+
+            if (!mimeTypeSet.intersect(collectionMimeTypeSet).isEmpty()) {
                 QString colId = QString::number(collection.id()).leftJustified(6, QLatin1Char(' '));
                 colId += QLatin1String("- ");
 
@@ -388,7 +399,6 @@ bool KonsoleKalendar::printEventList(QTextStream *ts, Event::List *eventList, QD
 bool KonsoleKalendar::printEvent(QTextStream *ts, const Event::Ptr &event, QDate dt)
 {
     bool status = false;
-    bool sameDay = true;
     KonsoleKalendarExports exports;
 
     if (event) {
@@ -399,14 +409,16 @@ bool KonsoleKalendar::printEvent(QTextStream *ts, const Event::Ptr &event, QDate
             status = exports.exportAsCSV(ts, event, dt);
             break;
 
-        case ExportTypeTextShort:
+        case ExportTypeTextShort: {
             qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendar.cpp::printEvent() |"
                                          << "TEXT-SHORT export";
+            bool sameDay = true;
             if (dt.daysTo(m_saveDate)) {
                 sameDay = false;
                 m_saveDate = dt;
             }
             status = exports.exportAsTxtShort(ts, event, dt, sameDay);
+        }
             break;
 
         case ExportTypeHTML:
