@@ -41,7 +41,7 @@
 #include <stdlib.h>
 #include <iostream>
 
-using namespace KCalCore;
+using namespace KCalendarCore;
 using namespace std;
 
 KonsoleKalendarChange::KonsoleKalendarChange(KonsoleKalendarVariables *vars)
@@ -135,7 +135,7 @@ bool KonsoleKalendarChange::changeEvent()
     return status;
 }
 
-void KonsoleKalendarChange::printSpecs(const KCalCore::Event::Ptr &event)
+void KonsoleKalendarChange::printSpecs(const KCalendarCore::Event::Ptr &event)
 {
     cout << i18n("  UID:   %1",
                  event->uid()).toLocal8Bit().data()
